FlutterSlider class

Inheritance

Constructors

FlutterSlider({Key? key, double? min, double? max, required List<double> values, List<FlutterSliderFixedValue>? fixedValues, Axis axis = Axis.horizontal, FlutterSliderHandler? handler, FlutterSliderHandler? rightHandler, double? handlerHeight, double? handlerWidth, dynamic onDragStarted(int handlerIndex, dynamic lowerValue, dynamic upperValue)?, dynamic onDragCompleted(int handlerIndex, dynamic lowerValue, dynamic upperValue)?, dynamic onDragging(int handlerIndex, dynamic lowerValue, dynamic upperValue)?, bool rangeSlider = false, bool rtl = false, bool jump = false, List<FlutterSliderIgnoreSteps> ignoreSteps = const [], bool disabled = false, double? touchSize, bool visibleTouchArea = false, double minimumDistance = 0, double maximumDistance = 0, FlutterSliderTooltip? tooltip, FlutterSliderTrackBar trackBar = const FlutterSliderTrackBar(), FlutterSliderHandlerAnimation handlerAnimation = const FlutterSliderHandlerAnimation(), bool selectByTap = true, FlutterSliderStep step = const FlutterSliderStep(), FlutterSliderHatchMark? hatchMark, bool centeredOrigin = false, bool lockHandlers = false, double? lockDistance, BoxDecoration? decoration, BoxDecoration? foregroundDecoration})

Properties

axis → Axis
final
centeredOrigin → bool
final
decoration → BoxDecoration?
final
disabled → bool
final
fixedValues → List<FlutterSliderFixedValue>?
final
foregroundDecoration → BoxDecoration?
final
handler → FlutterSliderHandler?
final
handlerAnimation → FlutterSliderHandlerAnimation
final
handlerHeight → double?
final
handlerWidth → double?
final
hashCode → int
The hash code for this object.
no setterinherited
hatchMark → FlutterSliderHatchMark?
final
ignoreSteps → List<FlutterSliderIgnoreSteps>
final
jump → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
final
lockDistance → double?
final
lockHandlers → bool
final
max → double?
final
maximumDistance → double
final
min → double?
final
minimumDistance → double
final
onDragCompleted → dynamic Function(int handlerIndex, dynamic lowerValue, dynamic upperValue)?
final
onDragging → dynamic Function(int handlerIndex, dynamic lowerValue, dynamic upperValue)?
final
onDragStarted → dynamic Function(int handlerIndex, dynamic lowerValue, dynamic upperValue)?
final
rangeSlider → bool
final
rightHandler → FlutterSliderHandler?
final
rtl → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectByTap → bool
final
step → FlutterSliderStep
final
tooltip → FlutterSliderTooltip?
final
touchSize → double?
final
trackBar → FlutterSliderTrackBar
final
values → List<double>
final
visibleTouchArea → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _FlutterSliderState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited