FlutterSliderHandler class

Constructors

FlutterSliderHandler({Widget? child, BoxDecoration? decoration, BoxDecoration? foregroundDecoration, Matrix4? transform, bool disabled = false, double opacity = 1})

Properties

child ↔ Widget?
getter/setter pair
decoration ↔ BoxDecoration?
getter/setter pair
disabled ↔ bool
getter/setter pair
foregroundDecoration ↔ BoxDecoration?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
opacity ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform ↔ Matrix4?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited