FlutterSliderHandlerAnimation class

Constructors

FlutterSliderHandlerAnimation({Curve curve = Curves.elasticOut, Curve? reverseCurve, Duration duration = const Duration(milliseconds: 700), double scale = 1.3})
const

Properties

curve → Curve
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
reverseCurve → Curve?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited