FlutterSliderSizedBox class

Constructors

FlutterSliderSizedBox({BoxDecoration? decoration, BoxDecoration? foregroundDecoration, Matrix4? transform, required double height, required double width})
const

Properties

decoration → BoxDecoration?
final
foregroundDecoration → BoxDecoration?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform → Matrix4?
final
width → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited