FlutterSliderTooltipBox class

Constructors

FlutterSliderTooltipBox({BoxDecoration? decoration, BoxDecoration? foregroundDecoration, Matrix4? transform})
const

Properties

decoration → BoxDecoration?
final
foregroundDecoration → BoxDecoration?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform → Matrix4?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited