FlutterSliderTrackBar class

Constructors

FlutterSliderTrackBar({BoxDecoration? inactiveTrackBar, BoxDecoration? activeTrackBar, Color activeDisabledTrackBarColor = const Color(0xffb5b5b5), Color inactiveDisabledTrackBarColor = const Color(0xffe5e5e5), double activeTrackBarHeight = 3.5, double inactiveTrackBarHeight = 3, Widget? centralWidget, bool activeTrackBarDraggable = true})
const

Properties

activeDisabledTrackBarColor → Color
final
activeTrackBar → BoxDecoration?
final
activeTrackBarDraggable → bool
final
activeTrackBarHeight → double
final
centralWidget → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveDisabledTrackBarColor → Color
final
inactiveTrackBar → BoxDecoration?
final
inactiveTrackBarHeight → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited